from os.path import isfile
from pathlib import Path
import logging
import os

import click
from traktor_nml_utils import TraktorCollection

logger = logging.getLogger(__name__)


def get_nml_files(directory):
    return [
        Path(file) for file in os.scandir(directory) if
        isfile(file) and file.name.endswith('.nml')
    ]


@click.group()
@click.option('-v', '--verbose', count=True, help="Verbose logging")
@click.option('-d', '--debug', help="Debug logging")
def cli(verbose, debug):
    loglevel = logging.WARNING
    if verbose:
        loglevel = logging.INFO
    elif debug:
        loglevel = logging.DEBUG
    logging.basicConfig(level=loglevel)


@cli.command()
@click.option('--nml-file', help="NML file to import")
def traktor_import_file(nml_file):
    TraktorCollection(nml_file)


@cli.command()
@click.option('--nml-dir', help="NML dir to import recursively")
def traktor_import_dir(nml_dir):
    for nml_file in get_nml_files(nml_dir):
        collection = TraktorCollection(str(nml_file))
        for entry in collection.entries:
            print(f"{nml_file} {entry.artist} - {entry.title}")


if __name__ == '__main__':
    cli()



import os

from setuptools import find_packages, setup


def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()


setup(
    name='traktor-nml-utils',
    version='2.0.4',
    description='Utilities to read and write Traktor NML files',
    long_description=read('README.pypi.md'),
    long_description_content_type='text/markdown',
    url='http://github.com/ifischer/traktor-nml-utils',
    author='Ingo Fischer',
    author_email='mail@ingofischer.de',
    license='GPL',
    packages=find_packages(exclude=('tests', 'docs')),
    zip_safe=True,
    python_requires='>=3.7.0',
    install_requires=[
        'xsdata',
    ],
)



def duration_str_to_milliseconds(duration_str: str):
    """
    Convert duration string (HH:MM:SS) to milliseconds for Cue points
    :param str duration_str: duration string (HH:MM:SS)
    :return:
    """
    h, m, s = duration_str.split(":")
    return float((int(h) * 3600 + int(m) * 60 + float(s)) * 1000)
